summaryrefslogtreecommitdiff
path: root/misc
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-06-30 18:40:41 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-06-30 18:40:41 -0600
commit8ae1ef74551af33cf18dd1cc4188c4def4fecf42 (patch)
tree42db9eb61e43dd7bd958f080d08cbe6544793d5b /misc
parent8299f4051ce03e4c56c08c93a81af0c36e24a2f0 (diff)
downloadnuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.tar.gz
nuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.tar.bz2
nuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.zip
Rename uip_poll->devif_poll and uip_timer->devif_timer
Diffstat (limited to 'misc')
-rw-r--r--misc/drivers/rtl8187x/rtl8187x.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/misc/drivers/rtl8187x/rtl8187x.c b/misc/drivers/rtl8187x/rtl8187x.c
index 81bd40a22..58fc34ee9 100644
--- a/misc/drivers/rtl8187x/rtl8187x.c
+++ b/misc/drivers/rtl8187x/rtl8187x.c
@@ -1931,7 +1931,7 @@ static int rtl8187x_transmit(FAR struct rtl8187x_state_s *priv)
*
* Description:
* The transmitter is available, check if uIP has any outgoing packets ready
* to send. This is a callback from uip_poll(). uip_poll() may be called:
*
* 1. When the preceding TX packet send is complete,
* 2. When the preceding TX packet send timesout and the interface is reset
@@ -2018,7 +2018,7 @@ static void rtl8187x_txpollwork(FAR void *arg)
*/
priv->ethdev.d_buf = &priv->txbuffer[SIZEOF_TXDESC];
- (void)uip_timer(&priv->ethdev, rtl8187x_uiptxpoll, (int)hsecs);
+ (void)devif_timer(&priv->ethdev, rtl8187x_uiptxpoll, (int)hsecs);
net_unlock(lock);
}
}
@@ -2522,7 +2522,7 @@ static int rtl8187x_txavail(struct net_driver_s *dev)
lock = net_lock();
priv->ethdev.d_buf = &priv->txbuffer[SIZEOF_TXDESC];
- (void)uip_poll(&priv->ethdev, rtl8187x_uiptxpoll);
+ (void)devif_poll(&priv->ethdev, rtl8187x_uiptxpoll);
net_unlock(lock);
}
@@ -1931,7 +1931,7 @@ static int rtl8187x_transmit(FAR struct rtl8187x_state_s *priv)
* Description:
* The transmitter is available, check if uIP has any outgoing packets ready
- * to send. This is a callback from uip_poll(). uip_poll() may be called:
+ * to send. This is a callback from devif_poll(). devif_poll() may be called:
*
* 1. When the preceding TX packet send is complete,